# This is a hack to prevent the RPM from depending on libGLcore.so.1 and
# libnvidia-tls.so.1 if it was built on a system that has the NVidia
# drivers installed.  The custom find-requires script is created during
# install and removed during clean
%define __find_requires %{_tmppath}/%{name}-%{version}-%{release}-find-requires

# Path under which VirtualGL should be installed
%define prefix /opt/VirtualGL

# Path under which executables and scripts should be installed
%define bindir /opt/VirtualGL/bin

# Create symlinks in %{_bindir} (usually /usr/bin), assuming
# %{bindir} != %{_bindir}
%define binsymlinks 1

%if "%{?__isa_bits:1}" == "1"
%define _bits %{__isa_bits}
%else
# RPM < 4.6
%if "%{_lib}" == "lib64"
%define _bits 64
%else
%define _bits 32
%endif
%endif

%if "%{_bits}" == "64"
%define _syslibdir /usr/lib64
%else
%define _syslibdir /usr/lib
%endif

# Path under which the VirtualGL faker libraries should be installed
%define libdir %{_syslibdir}

# Path under which the VirtualGL transport API headers should be installed
%define incdir /opt/VirtualGL/include

# Create symlinks in %{_includedir} (usually /usr/include), assuming
# %{incdir} != %{_includedir}
%define incsymlinks 1

# Path under which docs should be installed
%define docdir %{_defaultdocdir}/%{name}-%{version}

Summary: A toolkit for displaying OpenGL applications to thin clients
Name: VirtualGL
Version: 2.6.1
Vendor: The VirtualGL Project
URL: http://www.VirtualGL.org
Group: Applications/Graphics
Source0: http://prdownloads.sourceforge.net/virtualgl/VirtualGL-%{version}.tar.gz
Release: 20190101
License: wxWindows Library License v3.1
BuildRoot: %{_tmppath}/%{name}-buildroot-%{version}-%{release}
Provides: %{name}-libs = %{version}-%{release}
Obsoletes: %{name}-libs < %{version}-%{release}
BuildRequires: cmake libX11-devel libjpeg-turbo2
#BuildRequires: libjpeg-turbo-static turbojpeg-devel
BuildRequires: mesa-libGL-devel mesa-libGLU-devel libXext-devel libXv-devel libXtst-devel

%description
VirtualGL is a toolkit that allows most Linux/Unix OpenGL applications to be
remotely displayed with 3D hardware acceleration to thin clients, regardless of
whether the clients have 3D rendering capabilities, and regardless of the size
of the 3D data being rendered or the speed of the network.

Using the vglrun script, the VirtualGL Faker library is preloaded into an
OpenGL application at run time.  The faker then intercepts and modifies
("interposes") certain GLX, OpenGL, X11, and XCB function calls in order to
seamlessly redirect 3D rendering from the application's windows into
corresponding GPU-attached off-screen buffers, read back the rendered frames,
and transport the frames to the "2D X Server" (the X server to which the
application's GUI is being displayed), where the frames are composited back
into the application's windows.

VirtualGL can be used to give hardware-accelerated 3D rendering capabilities to
VNC and other X proxies that either lack OpenGL support or provide it through a
software renderer.  In a LAN environment, VGL can also be used with its
built-in high-performance image transport (the VGL Transport), which sends the
rendered frames to the VirtualGL Client application for compositing on a
client-side 2D X server.  VirtualGL also supports image transport plugins,
allowing the rendered frames to be sent or captured using other mechanisms.

VirtualGL is based upon ideas presented in various academic papers on this
topic, including "A Generic Solution for Hardware-Accelerated Remote
Visualization" (Stegmaier, Magallon, Ertl 2002) and "A Framework for
Interactive Hardware Accelerated Remote 3D-Visualization" (Engel, Sommer,
Ertl 2000.)

%prep
%setup -q -n VirtualGL-%{version}

%build
cmake -G"Unix Makefiles" -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DBUILD=%{release} -DCMAKE_INSTALL_BINDIR=%{bindir} \
  -DCMAKE_INSTALL_DOCDIR=%{docdir} -DCMAKE_INSTALL_INCLUDEDIR=%{incdir} \
  -DCMAKE_INSTALL_LIBDIR=%{libdir} -DCMAKE_INSTALL_PREFIX=%{prefix} \
  -DVGL_BUILDSERVER=1 -DVGL_SYSTEMFLTK=OFF \
  -DVGL_SYSTEMGLX=OFF -DVGL_SYSTEMXCB=OFF \
  -DVGL_USESSL=0 -DVGL_USEXV=1
export NUMCPUS=`grep -c '^processor' /proc/cpuinfo`
make -j$NUMCPUS --load-average=$NUMCPUS

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
rm $RPM_BUILD_ROOT/%{bindir}/.vglrun.vars*

%if "%{bindir}" != "%{_bindir}" && %{binsymlinks}
mkdir -p $RPM_BUILD_ROOT/%{_bindir}
pushd $RPM_BUILD_ROOT/%{bindir}
for i in vgl*; do
	ln -fs %{bindir}/$i $RPM_BUILD_ROOT/%{_bindir}/
done
popd
%endif

%if "%{incdir}" != "%{_includedir}" && %{incsymlinks}
mkdir -p $RPM_BUILD_ROOT/%{_includedir}
pushd $RPM_BUILD_ROOT/%{incdir}
for i in *; do
	ln -fs %{incdir}/$i $RPM_BUILD_ROOT/%{_includedir}/
done
popd
%endif

%if 0

# This is only needed to support in-tree RPM generation via 'make rpm'.  When
# building from a SRPM, we control where things are installed via CMake
# variables.

safedirmove ()
{
	if [ "$1" = "$2" ]; then
		return 0
	fi
	if [ "$1" = "" -o ! -d "$1" ]; then
		echo safedirmove: source dir $1 is not valid
		return 1
	fi
	if [ "$2" = "" -o -e "$2" ]; then
		echo safedirmove: dest dir $2 is not valid
		return 1
	fi
	if [ "$3" = "" -o -e "$3" ]; then
		echo safedirmove: tmp dir $3 is not valid
		return 1
	fi
	mkdir -p $3
	mv $1/* $3/
	rmdir $1
	mkdir -p $2
	mv $3/* $2/
	rmdir $3
	return 0
}

VGL_DOCDIR=/opt/VirtualGL/doc
if [ ! "$VGL_DOCDIR" = "%{docdir}" ]; then
	safedirmove $RPM_BUILD_ROOT/$VGL_DOCDIR $RPM_BUILD_ROOT/%{docdir} $RPM_BUILD_ROOT/__tmpdoc
fi

VGL_LIBDIR=/opt/VirtualGL/lib64
if [ ! "$VGL_LIBDIR" = "%{libdir}" ]; then
	safedirmove $RPM_BUILD_ROOT/$VGL_LIBDIR $RPM_BUILD_ROOT/%{libdir} $RPM_BUILD_ROOT/__tmplib
fi

%endif

%if "%{prefix}" == "/opt/VirtualGL" && "%{docdir}" != "%{prefix}/doc"
	ln -fs %{docdir} $RPM_BUILD_ROOT/%{prefix}/doc
%endif

echo '/usr/lib/rpm/find-requires|grep -v libGLcore|grep -v libnvidia-tls' >%{_tmppath}/%{name}-%{version}-%{release}-find-requires
chmod 755 %{_tmppath}/%{name}-%{version}-%{release}-find-requires

mkdir -p $RPM_BUILD_ROOT/opt/share/Modules/modulefiles/virtualgl
cat > $RPM_BUILD_ROOT/opt/share/Modules/modulefiles/virtualgl/%{version} <<ENDMODULE
#%Module

proc ModulesHelp { } {
   puts stderr "This module adds VirtualGL to various paths"
}

module-whatis   "Sets up VirtualGL in your environment"

prepend-path PATH "%{bindir}"
ENDMODULE

%clean
rm -rf $RPM_BUILD_ROOT
rm %{_tmppath}/%{name}-%{version}-%{release}-find-requires

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%files -n %{name}
%defattr(-,root,root)

%dir %{prefix}
%if "%{prefix}" == "/opt/VirtualGL" && "%{docdir}" != "%{prefix}/doc"
	%{prefix}/doc
%endif

%dir %{docdir}
%doc %{docdir}/*

%dir %{bindir}
%{bindir}/glreadtest
%{bindir}/tcbench
%{bindir}/nettest
%{bindir}/cpustat
%{bindir}/glxinfo
%{bindir}/vglclient
%{bindir}/vglconfig
%{bindir}/vglconnect
%{bindir}/vglgenkey
%{bindir}/vgllogin
%{bindir}/vglserver_config
%{bindir}/vglrun
%if "%{_bits}" == "64"
	%{bindir}/glxspheres64
%else
	%{bindir}/glxspheres
%endif
%if "%{bindir}" != "%{_bindir}" && %{binsymlinks}
	%{_bindir}/vglclient
	%{_bindir}/vglconfig
	%{_bindir}/vglconnect
	%{_bindir}/vgllogin
	%{_bindir}/vglrun
	%{_bindir}/vglgenkey
	%{_bindir}/vglserver_config
%endif

%dir %{incdir}
%{incdir}/rrtransport.h
%{incdir}/rr.h
%if "%{incdir}" != "%{_includedir}" && %{incsymlinks}
	%{_includedir}/rrtransport.h
	%{_includedir}/rr.h
%endif
%dir /opt/share/Modules/modulefiles/virtualgl
/opt/share/Modules/modulefiles/virtualgl/%{version}

%if "%{libdir}" != "%{_syslibdir}"
%dir %{libdir}
%endif
%{libdir}/libvglfaker.so
%{libdir}/libvglfaker-nodl.so
%{libdir}/libdlfaker.so
%{libdir}/libgefaker.so

%changelog
